@@ -1,44 +1,47 @@
 
 /* Compiler implementation of the D programming language
- * Copyright (C) 1999-2018 by The D Language Foundation, All Rights Reserved
+ * Copyright (C) 1999-2019 by The D Language Foundation, All Rights Reserved
  * written by Walter Bright
  * http://www.digitalmars.com
  * Distributed under the Boost Software License, Version 1.0.
  * http://www.boost.org/LICENSE_1_0.txt
- * https://github.com/dlang/dmd/blob/master/src/cond.h
+ * https://github.com/dlang/dmd/blob/master/src/dmd/cond.h
  */
 
-#ifndef DMD_DEBCOND_H
-#define DMD_DEBCOND_H
+#pragma once
 
+#include "ast_node.h"
 #include "globals.h"
 #include "visitor.h"
 
 class Expression;
 class Identifier;
-struct OutBuffer;
 class Module;
 struct Scope;
-class ScopeDsymbol;
 class DebugCondition;
 class ForeachStatement;
 class ForeachRangeStatement;
 
 int findCondition(Strings *ids, Identifier *ident);
 
-class Condition
+enum Include
+{
+    INCLUDEnotComputed, /// not computed yet
+    INCLUDEyes,         /// include the conditional code
+    INCLUDEno           /// do not include the conditional code
+};
+
+class Condition : public ASTNode
 {
 public:
     Loc loc;
-    // 0: not computed yet
-    // 1: include
-    // 2: do not include
-    int inc;
+    Include inc;
 
     virtual Condition *syntaxCopy() = 0;
     virtual int include(Scope *sc) = 0;
     virtual DebugCondition *isDebugCondition() { return NULL; }
-    virtual void accept(Visitor *v) { v->visit(this); }
+    virtual VersionCondition *isVersionCondition() { return NULL; }
+    void accept(Visitor *v) { v->visit(this); }
 };
 
 class StaticForeach
@@ -82,6 +85,7 @@ public:
     static void addPredefinedGlobalIdent(const char *ident);
 
     int include(Scope *sc);
+    VersionCondition *isVersionCondition() { return this; }
     void accept(Visitor *v) { v->visit(this); }
 };
 
@@ -95,5 +99,3 @@ public:
     int include(Scope *sc);
     void accept(Visitor *v) { v->visit(this); }
 };
-
-#endif
