@@ -585,6 +585,7 @@ class SymbolExp : public Expression
 public:
     Declaration *var;
     bool hasOverloads;
+    Dsymbol *originalScope;
 
     void accept(Visitor *v) { v->visit(this); }
 };
@@ -819,6 +820,7 @@ class DelegateExp : public UnaExp
 public:
     FuncDeclaration *func;
     bool hasOverloads;
+    VarDeclaration *vthis2;  // container for multi-context
 
 
     void accept(Visitor *v) { v->visit(this); }
@@ -838,6 +840,7 @@ public:
     Expressions *arguments;     // function arguments
     FuncDeclaration *f;         // symbol to call
     bool directcall;            // true if a virtual call is devirtualized
+    VarDeclaration *vthis2;     // container for multi-context
 
     static CallExp *create(Loc loc, Expression *e, Expressions *exps);
     static CallExp *create(Loc loc, Expression *e);
