@@ -1,28 +1,21 @@
 
 /* Compiler implementation of the D programming language
- * Copyright (C) 1999-2018 by The D Language Foundation, All Rights Reserved
+ * Copyright (C) 1999-2019 by The D Language Foundation, All Rights Reserved
  * written by Walter Bright
  * http://www.digitalmars.com
  * Distributed under the Boost Software License, Version 1.0.
  * http://www.boost.org/LICENSE_1_0.txt
- * https://github.com/dlang/dmd/blob/master/src/import.h
+ * https://github.com/dlang/dmd/blob/master/src/dmd/import.h
  */
 
-#ifndef DMD_IMPORT_H
-#define DMD_IMPORT_H
-
-#ifdef __DMC__
 #pragma once
-#endif /* __DMC__ */
 
 #include "dsymbol.h"
 
-
 class Identifier;
 struct Scope;
 class Module;
 class Package;
-class AliasDeclaration;
 
 class Import : public Dsymbol
 {
@@ -60,5 +53,3 @@ public:
     Import *isImport() { return this; }
     void accept(Visitor *v) { v->visit(this); }
 };
-
-#endif /* DMD_IMPORT_H */
