@@ -1,27 +1,23 @@
 
 /* Compiler implementation of the D programming language
- * Copyright (C) 1999-2018 by The D Language Foundation, All Rights Reserved
+ * Copyright (C) 1999-2019 by The D Language Foundation, All Rights Reserved
  * written by Walter Bright
  * http://www.digitalmars.com
  * Distributed under the Boost Software License, Version 1.0.
  * http://www.boost.org/LICENSE_1_0.txt
- * https://github.com/dlang/dmd/blob/master/src/init.h
+ * https://github.com/dlang/dmd/blob/master/src/dmd/init.h
  */
 
-#ifndef INIT_H
-#define INIT_H
+#pragma once
 
-#include "root.h"
-
-#include "mars.h"
+#include "ast_node.h"
+#include "globals.h"
 #include "arraytypes.h"
 #include "visitor.h"
 
 class Identifier;
 class Expression;
-struct Scope;
 class Type;
-class AggregateDeclaration;
 class ErrorInitializer;
 class VoidInitializer;
 class StructInitializer;
@@ -30,22 +26,21 @@ class ExpInitializer;
 
 enum NeedInterpret { INITnointerpret, INITinterpret };
 
-class Initializer : public RootObject
+class Initializer : public ASTNode
 {
 public:
     Loc loc;
-
-    virtual Initializer *syntaxCopy() = 0;
-    static Initializers *arraySyntaxCopy(Initializers *ai);
+    unsigned char kind;
 
     const char *toChars();
 
-    virtual ErrorInitializer   *isErrorInitializer() { return NULL; }
-    virtual VoidInitializer    *isVoidInitializer() { return NULL; }
-    virtual StructInitializer  *isStructInitializer()  { return NULL; }
-    virtual ArrayInitializer   *isArrayInitializer()  { return NULL; }
-    virtual ExpInitializer     *isExpInitializer()  { return NULL; }
-    virtual void accept(Visitor *v) { v->visit(this); }
+    ErrorInitializer   *isErrorInitializer();
+    VoidInitializer    *isVoidInitializer();
+    StructInitializer  *isStructInitializer();
+    ArrayInitializer   *isArrayInitializer();
+    ExpInitializer     *isExpInitializer();
+
+    void accept(Visitor *v) { v->visit(this); }
 };
 
 class VoidInitializer : public Initializer
@@ -53,18 +48,12 @@ class VoidInitializer : public Initializer
 public:
     Type *type;         // type that this will initialize to
 
-    Initializer *syntaxCopy();
-
-    virtual VoidInitializer *isVoidInitializer() { return this; }
     void accept(Visitor *v) { v->visit(this); }
 };
 
 class ErrorInitializer : public Initializer
 {
 public:
-    Initializer *syntaxCopy();
-
-    virtual ErrorInitializer *isErrorInitializer() { return this; }
     void accept(Visitor *v) { v->visit(this); }
 };
 
@@ -74,10 +63,8 @@ public:
     Identifiers field;  // of Identifier *'s
     Initializers value; // parallel array of Initializer *'s
 
-    Initializer *syntaxCopy();
     void addInit(Identifier *field, Initializer *value);
 
-    StructInitializer *isStructInitializer() { return this; }
     void accept(Visitor *v) { v->visit(this); }
 };
 
@@ -90,25 +77,23 @@ public:
     Type *type;         // type that array will be used to initialize
     bool sem;           // true if semantic() is run
 
-    Initializer *syntaxCopy();
     void addInit(Expression *index, Initializer *value);
-    bool isAssociativeArray();
+    bool isAssociativeArray() const;
     Expression *toAssocArrayLiteral();
 
-    ArrayInitializer *isArrayInitializer() { return this; }
     void accept(Visitor *v) { v->visit(this); }
 };
 
 class ExpInitializer : public Initializer
 {
 public:
-    Expression *exp;
     bool expandTuples;
+    Expression *exp;
 
-    Initializer *syntaxCopy();
-
-    ExpInitializer *isExpInitializer() { return this; }
     void accept(Visitor *v) { v->visit(this); }
 };
 
-#endif
+Expression *initializerToExpression(Initializer *init, Type *t = NULL);
+
+Initializer *syntaxCopy(Initializer *inx);
+
