@@ -24,6 +24,7 @@ class UserAttributeDeclaration;
 struct DocComment;
 struct AA;
 class TemplateInstance;
+class CPPNamespaceDeclaration;
 
 #include "dsymbol.h"
 
@@ -91,6 +92,9 @@ struct Scope
 
     AlignDeclaration *aligndecl;    // alignment for struct members
 
+    /// C++ namespace this symbol belongs to
+    CPPNamespaceDeclaration *namespace_;
+
     LINK linkage;               // linkage for external functions
     CPPMANGLE cppmangle;        // C++ mangle type
     PINLINE inlining;            // inlining strategy for functions
@@ -142,5 +146,5 @@ struct Scope
 
     structalign_t alignment();
 
-    bool isDeprecated();
+    bool isDeprecated() const;
 };
