@@ -1,28 +1,21 @@
 
 /* Compiler implementation of the D programming language
- * Copyright (C) 1999-2018 by The D Language Foundation, All Rights Reserved
+ * Copyright (C) 1999-2019 by The D Language Foundation, All Rights Reserved
  * written by Walter Bright
  * http://www.digitalmars.com
  * Distributed under the Boost Software License, Version 1.0.
  * http://www.boost.org/LICENSE_1_0.txt
- * https://github.com/dlang/dmd/blob/master/src/statement.h
+ * https://github.com/dlang/dmd/blob/master/src/dmd/statement.h
  */
 
-#ifndef DMD_STATEMENT_H
-#define DMD_STATEMENT_H
-
-#ifdef __DMC__
 #pragma once
-#endif /* __DMC__ */
-
-#include "root.h"
 
 #include "arraytypes.h"
+#include "ast_node.h"
 #include "dsymbol.h"
 #include "visitor.h"
 #include "tokens.h"
 
-struct OutBuffer;
 struct Scope;
 class Expression;
 class LabelDsymbol;
@@ -32,8 +25,6 @@ class ExpStatement;
 class DefaultStatement;
 class VarDeclaration;
 class Condition;
-class Module;
-struct Token;
 class ErrorStatement;
 class ReturnStatement;
 class CompoundStatement;
@@ -50,14 +41,9 @@ class LabelStatement;
 class StaticForeach;
 
 #if IN_LLVM
-namespace llvm
-{
+namespace llvm {
     class Value;
-    class BasicBlock;
-    class ConstantInt;
 }
-class DValue;
-typedef DValue elem;
 struct AsmCode;
 typedef AsmCode code;
 #else
@@ -81,25 +67,24 @@ enum BE
     BEbreak =    0x20,
     BEcontinue = 0x40,
     BEerrthrow = 0x80,
-    BEany = (BEfallthru | BEthrow | BEreturn | BEgoto | BEhalt),
+    BEany = (BEfallthru | BEthrow | BEreturn | BEgoto | BEhalt)
 };
 
-class Statement : public RootObject
+class Statement : public ASTNode
 {
 public:
     Loc loc;
 
     virtual Statement *syntaxCopy();
 
-    void print();
     const char *toChars();
 
     void error(const char *format, ...);
     void warning(const char *format, ...);
     void deprecation(const char *format, ...);
     virtual Statement *getRelatedLabeled() { return this; }
-    virtual bool hasBreak();
-    virtual bool hasContinue();
+    virtual bool hasBreak() const;
+    virtual bool hasContinue() const;
     bool usesEH();
     bool comeFrom();
     bool hasCode();
@@ -122,10 +107,10 @@ public:
     virtual BreakStatement *isBreakStatement() { return NULL; }
     virtual DtorExpStatement *isDtorExpStatement() { return NULL; }
     virtual ForwardingStatement *isForwardingStatement() { return NULL; }
-    virtual void accept(Visitor *v) { v->visit(this); }
+    void accept(Visitor *v) { v->visit(this); }
 
 #if IN_LLVM
-    virtual CompoundAsmStatement *isCompoundAsmBlockStatement() { return NULL; }
+    virtual CompoundAsmStatement *isCompoundAsmBlockStatement() { return nullptr; }
     virtual CompoundAsmStatement *endsWithAsm();
 #endif
 };
@@ -181,7 +166,7 @@ public:
 class CompileStatement : public Statement
 {
 public:
-    Expression *exp;
+    Expressions *exps;
 
     Statement *syntaxCopy();
     Statements *flatten(Scope *sc);
@@ -223,8 +208,8 @@ public:
     Statements *statements;
 
     Statement *syntaxCopy();
-    bool hasBreak();
-    bool hasContinue();
+    bool hasBreak() const;
+    bool hasContinue() const;
 
     void accept(Visitor *v) { v->visit(this); }
 };
@@ -238,8 +223,8 @@ public:
     Statement *syntaxCopy();
     ScopeStatement *isScopeStatement() { return this; }
     ReturnStatement *isReturnStatement();
-    bool hasBreak();
-    bool hasContinue();
+    bool hasBreak() const;
+    bool hasContinue() const;
 
     void accept(Visitor *v) { v->visit(this); }
 };
@@ -263,8 +248,8 @@ public:
     Loc endloc;                 // location of closing curly bracket
 
     Statement *syntaxCopy();
-    bool hasBreak();
-    bool hasContinue();
+    bool hasBreak() const;
+    bool hasContinue() const;
 
     void accept(Visitor *v) { v->visit(this); }
 };
@@ -277,8 +262,8 @@ public:
     Loc endloc;                 // location of ';' after while
 
     Statement *syntaxCopy();
-    bool hasBreak();
-    bool hasContinue();
+    bool hasBreak() const;
+    bool hasContinue() const;
 
     void accept(Visitor *v) { v->visit(this); }
 };
@@ -300,8 +285,8 @@ public:
     Statement *syntaxCopy();
     Statement *scopeCode(Scope *sc, Statement **sentry, Statement **sexit, Statement **sfinally);
     Statement *getRelatedLabeled() { return relatedLabeled ? relatedLabeled : this; }
-    bool hasBreak();
-    bool hasContinue();
+    bool hasBreak() const;
+    bool hasContinue() const;
 
     void accept(Visitor *v) { v->visit(this); }
 };
@@ -324,9 +309,8 @@ public:
     ScopeStatements *gotos;     // forward referenced goto's go here
 
     Statement *syntaxCopy();
-    bool checkForArgTypes();
-    bool hasBreak();
-    bool hasContinue();
+    bool hasBreak() const;
+    bool hasContinue() const;
 
     void accept(Visitor *v) { v->visit(this); }
 };
@@ -344,8 +328,8 @@ public:
     VarDeclaration *key;
 
     Statement *syntaxCopy();
-    bool hasBreak();
-    bool hasContinue();
+    bool hasBreak() const;
+    bool hasContinue() const;
 
     void accept(Visitor *v) { v->visit(this); }
 };
@@ -432,8 +416,7 @@ public:
 #endif
 
     Statement *syntaxCopy();
-    bool hasBreak();
-    bool checkLabel();
+    bool hasBreak() const;
 
     void accept(Visitor *v) { v->visit(this); }
 };
@@ -572,8 +555,8 @@ public:
     Statement *_body;
 
     Statement *syntaxCopy();
-    bool hasBreak();
-    bool hasContinue();
+    bool hasBreak() const;
+    bool hasContinue() const;
 
     void accept(Visitor *v) { v->visit(this); }
 };
@@ -598,7 +581,7 @@ public:
     Catches *catches;
 
     Statement *syntaxCopy();
-    bool hasBreak();
+    bool hasBreak() const;
 
     void accept(Visitor *v) { v->visit(this); }
 };
@@ -609,9 +592,9 @@ public:
     Loc loc;
     Type *type;
     Identifier *ident;
-    VarDeclaration *var;
     Statement *handler;
 
+    VarDeclaration *var;
     // set if semantic processing errors
     bool errors;
 
@@ -632,13 +615,13 @@ public:
 
     static TryFinallyStatement *create(Loc loc, Statement *body, Statement *finalbody);
     Statement *syntaxCopy();
-    bool hasBreak();
-    bool hasContinue();
+    bool hasBreak() const;
+    bool hasContinue() const;
 
     void accept(Visitor *v) { v->visit(this); }
 };
 
-class OnScopeStatement : public Statement
+class ScopeGuardStatement : public Statement
 {
 public:
     TOK tok;
@@ -679,11 +662,10 @@ public:
     Identifier *ident;
     LabelDsymbol *label;
     TryFinallyStatement *tf;
-    OnScopeStatement *os;
+    ScopeGuardStatement *os;
     VarDeclaration *lastVar;
 
     Statement *syntaxCopy();
-    bool checkLabel();
 
     void accept(Visitor *v) { v->visit(this); }
 };
@@ -694,7 +676,7 @@ public:
     Identifier *ident;
     Statement *statement;
     TryFinallyStatement *tf;
-    OnScopeStatement *os;
+    ScopeGuardStatement *os;
     VarDeclaration *lastVar;
     Statement *gotoTarget;      // interpret
 
@@ -741,9 +723,7 @@ public:
 
 #if IN_LLVM
     // non-zero if this is a branch, contains the target label
-    LabelDsymbol* isBranchToLabel;
-
-    static InlineAsmStatement *create(const Loc &loc, Token *tokens);
+    LabelDsymbol *isBranchToLabel;
 #endif
 
     Statement *syntaxCopy();
@@ -784,7 +764,7 @@ public:
     void accept(Visitor *v) { v->visit(this); }
 
 #if IN_LLVM
-    CompoundStatement *isCompoundStatement() { return NULL; }
+    CompoundStatement *isCompoundStatement() { return nullptr; }
     CompoundAsmStatement *isCompoundAsmBlockStatement() { return this; }
 
     CompoundAsmStatement* endsWithAsm();
@@ -800,5 +780,3 @@ public:
 
     void accept(Visitor *v) { v->visit(this); }
 };
-
-#endif /* DMD_STATEMENT_H */
