@@ -1,22 +1,17 @@
 
 /* Compiler implementation of the D programming language
- * Copyright (C) 1999-2018 by The D Language Foundation, All Rights Reserved
+ * Copyright (C) 1999-2019 by The D Language Foundation, All Rights Reserved
  * written by Walter Bright
  * http://www.digitalmars.com
  * Distributed under the Boost Software License, Version 1.0.
  * http://www.boost.org/LICENSE_1_0.txt
- * https://github.com/dlang/dmd/blob/master/src/tokens.h
+ * https://github.com/dlang/dmd/blob/master/src/dmd/tokens.h
  */
 
-#ifndef DMD_TOKENS_H
-#define DMD_TOKENS_H
-
-#ifdef __DMC__
 #pragma once
-#endif /* __DMC__ */
 
-#include "port.h"
-#include "mars.h"
+#include "root/port.h"
+#include "globals.h"
 
 class Identifier;
 
@@ -36,7 +31,13 @@ class Identifier;
         ?       &&      ||
  */
 
+#if IN_LLVM
+// https://issues.dlang.org/show_bug.cgi?id=19658
 enum TOK
+#else
+typedef unsigned char TOK;
+enum
+#endif
 {
         TOKreserved,
 
@@ -185,12 +186,19 @@ enum TOK
         TOKshowctfecontext,
 
         TOKobjc_class_reference,
+        TOKvectorarray,
 
         TOKMAX
 };
 
 #define TOKwild TOKinout
 
+// Token has an anonymous struct, which is not strict ISO C++.
+#if defined(__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpedantic"
+#endif
+
 struct Token
 {
     Token *next;
@@ -217,19 +225,15 @@ struct Token
         Identifier *ident;
     };
 
-    static const char *tochars[TOKMAX];
-
-    static Token *freelist;
-    static Token *alloc();
     void free();
 
     Token() : next(NULL) {}
     int isKeyword();
-#ifdef DEBUG
-    void print();
-#endif
     const char *toChars() const;
-    static const char *toChars(TOK);
+
+    static const char *toChars(TOK value);
 };
 
-#endif /* DMD_TOKENS_H */
+#if defined(__GNUC__)
+#pragma GCC diagnostic pop
+#endif
