@@ -28,12 +28,12 @@ typedef Array<const char *> Strings;
 namespace opts {
 namespace cl = llvm::cl;
 
-/// Duplicate the string and replace '/' with '\' on Windows.
-char *dupPathString(llvm::StringRef src);
+/// Duplicate the string (incl. null-termination) and replace '/' with '\' on
+/// Windows.
+DArray<const char> dupPathString(llvm::StringRef src);
 
 /// Helper function to handle -of, -od, etc.
-/// llvm::cl::opt<std::string> --> char*
-void initFromPathString(const char *&dest, const cl::opt<std::string> &src);
+DArray<const char> fromPathString(const cl::opt<std::string> &src);
 
 /// Helper class to determine values
 template <class DT> struct FlagParserDataType {};
