@@ -19,30 +19,25 @@
 #define LLVM_DEBUG DEBUG
 #endif
 
-#include "Passes.h"
-#include "llvm/Pass.h"
-#include "llvm/IR/Module.h"
+#include "gen/passes/Passes.h"
+#include "gen/tollvm.h"
+#include "gen/runtime.h"
+#include "llvm/ADT/Statistic.h"
+#include "llvm/ADT/StringMap.h"
+#include "llvm/IR/DataLayout.h"
 #include "llvm/IR/Function.h"
 #include "llvm/IR/Intrinsics.h"
 #include "llvm/IR/IRBuilder.h"
-#include "llvm/IR/DataLayout.h"
+#include "llvm/IR/Module.h"
 #include "llvm/Analysis/AliasAnalysis.h"
 #include "llvm/Analysis/ValueTracking.h"
-#include "llvm/ADT/StringMap.h"
-#include "llvm/ADT/Statistic.h"
+#include "llvm/Pass.h"
 #include "llvm/Support/Compiler.h"
 #include "llvm/Support/Debug.h"
 #include "llvm/Support/raw_ostream.h"
-#include "gen/runtime.h"
 
 using namespace llvm;
 
-#if LDC_LLVM_VER >= 308
-typedef AAResultsWrapperPass AliasAnalysisPass;
-#else
-typedef AliasAnalysis AliasAnalysisPass;
-#endif
-
 STATISTIC(NumSimplified, "Number of runtime calls simplified");
 STATISTIC(NumDeleted, "Number of runtime calls deleted");
 
@@ -170,55 +165,6 @@ struct LLVM_LIBRARY_VISIBILITY ArraySetLengthOpt : public LibCallOptimization {
   }
 };
 
-/// ArrayCastLenOpt - remove libcall for cast(T[]) arr if it's safe to do so.
-struct LLVM_LIBRARY_VISIBILITY ArrayCastLenOpt : public LibCallOptimization {
-  Value *CallOptimizer(Function *Callee, CallInst *CI,
-                       IRBuilder<> &B) override {
-    // Verify we have a reasonable prototype for _d_array_cast_len
-    const FunctionType *FT = Callee->getFunctionType();
-    const llvm::Type *RetTy = FT->getReturnType();
-    if (Callee->arg_size() != 3 || !isa<IntegerType>(RetTy) ||
-        FT->getParamType(0) != RetTy || FT->getParamType(1) != RetTy ||
-        FT->getParamType(2) != RetTy) {
-      return nullptr;
-    }
-
-    Value *OldLen = CI->getOperand(0);
-    Value *OldSize = CI->getOperand(1);
-    Value *NewSize = CI->getOperand(2);
-
-    // If the old length was zero, always return zero.
-    if (Constant *LenCst = dyn_cast<Constant>(OldLen)) {
-      if (LenCst->isNullValue()) {
-        return OldLen;
-      }
-    }
-
-    // Equal sizes are much faster to check for, so do so now.
-    if (OldSize == NewSize) {
-      return OldLen;
-    }
-
-    // If both sizes are constant integers, see if OldSize is a multiple of
-    // NewSize
-    if (ConstantInt *OldInt = dyn_cast<ConstantInt>(OldSize)) {
-      if (ConstantInt *NewInt = dyn_cast<ConstantInt>(NewSize)) {
-        // Don't crash on NewSize == 0, even though it shouldn't happen.
-        if (NewInt->isNullValue()) {
-          return nullptr;
-        }
-
-        APInt Quot, Rem;
-        APInt::udivrem(OldInt->getValue(), NewInt->getValue(), Quot, Rem);
-        if (Rem == 0) {
-          return B.CreateMul(OldLen, ConstantInt::get(*Context, Quot));
-        }
-      }
-    }
-    return nullptr;
-  }
-};
-
 /// AllocationOpt - Common optimizations for various GC allocations.
 struct LLVM_LIBRARY_VISIBILITY AllocationOpt : public LibCallOptimization {
   Value *CallOptimizer(Function *Callee, CallInst *CI,
@@ -267,27 +213,28 @@ struct LLVM_LIBRARY_VISIBILITY ArraySliceCopyOpt : public LibCallOptimization {
     // Verify we have a reasonable prototype for _d_array_slice_copy
     const FunctionType *FT = Callee->getFunctionType();
     const llvm::Type *VoidPtrTy = PointerType::getUnqual(B.getInt8Ty());
-    if (Callee->arg_size() != 4 || FT->getReturnType() != B.getVoidTy() ||
+    if (Callee->arg_size() != 5 || FT->getReturnType() != B.getVoidTy() ||
         FT->getParamType(0) != VoidPtrTy ||
         !isa<IntegerType>(FT->getParamType(1)) ||
         FT->getParamType(2) != VoidPtrTy ||
-        FT->getParamType(3) != FT->getParamType(1)) {
+        FT->getParamType(3) != FT->getParamType(1) ||
+        FT->getParamType(4) != FT->getParamType(1)) {
       return nullptr;
     }
 
-    Value *Size = CI->getOperand(1);
+    Value *DstLength = CI->getOperand(1);
 
     // Check the lengths match
-    if (CI->getOperand(3) != Size) {
+    if (CI->getOperand(3) != DstLength) {
       return nullptr;
     }
 
-    // Assume unknown size unless we have constant size (that fits in an uint)
-    unsigned Sz = ~0U;
-    if (ConstantInt *Int = dyn_cast<ConstantInt>(Size)) {
-      if (Int->getValue().isIntN(32)) {
-        Sz = Int->getValue().getZExtValue();
-      }
+    const auto ElemSz = llvm::cast<ConstantInt>(CI->getOperand(4));
+
+    // Assume unknown size unless we have constant length
+    std::uint64_t Sz = llvm::MemoryLocation::UnknownSize;
+    if (ConstantInt *Int = dyn_cast<ConstantInt>(DstLength)) {
+      Sz = (Int->getValue() * ElemSz->getValue()).getZExtValue();
     }
 
     // Check if the pointers may alias
@@ -297,6 +244,9 @@ struct LLVM_LIBRARY_VISIBILITY ArraySliceCopyOpt : public LibCallOptimization {
 
     // Equal length and the pointers definitely don't alias, so it's safe to
     // replace the call with memcpy
+    auto Size = Sz != llvm::MemoryLocation::UnknownSize
+                    ? DtoConstSize_t(Sz)
+                    : B.CreateMul(DstLength, ElemSz);
     return EmitMemCpy(CI->getOperand(0), CI->getOperand(2), Size, 1, B);
   }
 };
@@ -317,7 +267,6 @@ class LLVM_LIBRARY_VISIBILITY SimplifyDRuntimeCalls : public FunctionPass {
 
   // Array operations
   ArraySetLengthOpt ArraySetLength;
-  ArrayCastLenOpt ArrayCastLen;
   ArraySliceCopyOpt ArraySliceCopy;
 
   // GC allocations
@@ -330,10 +279,10 @@ public:
   void InitOptimizations();
   bool runOnFunction(Function &F) override;
 
-  bool runOnce(Function &F, const DataLayout *DL, AliasAnalysisPass &AA);
+  bool runOnce(Function &F, const DataLayout *DL, AAResultsWrapperPass &AA);
 
   void getAnalysisUsage(AnalysisUsage &AU) const override {
-    AU.addRequired<AliasAnalysisPass>();
+    AU.addRequired<AAResultsWrapperPass>();
   }
 };
 char SimplifyDRuntimeCalls::ID = 0;
@@ -353,7 +302,6 @@ void SimplifyDRuntimeCalls::InitOptimizations() {
   // Some array-related optimizations
   Optimizations["_d_arraysetlengthT"] = &ArraySetLength;
   Optimizations["_d_arraysetlengthiT"] = &ArraySetLength;
-  Optimizations["_d_array_cast_len"] = &ArrayCastLen;
   Optimizations["_d_array_slice_copy"] = &ArraySliceCopy;
 
   /* Delete calls to runtime functions which aren't needed if their result is
@@ -384,7 +332,7 @@ bool SimplifyDRuntimeCalls::runOnFunction(Function &F) {
   }
 
   const DataLayout *DL = &F.getParent()->getDataLayout();
-  AliasAnalysisPass &AA = getAnalysis<AliasAnalysisPass>();
+  AAResultsWrapperPass &AA = getAnalysis<AAResultsWrapperPass>();
 
   // Iterate to catch opportunities opened up by other optimizations,
   // such as calls that are only used as arguments to unused calls:
@@ -402,7 +350,7 @@ bool SimplifyDRuntimeCalls::runOnFunction(Function &F) {
 }
 
 bool SimplifyDRuntimeCalls::runOnce(Function &F, const DataLayout *DL,
-                                    AliasAnalysisPass &AAP) {
+                                    AAResultsWrapperPass &AAP) {
   IRBuilder<> Builder(F.getContext());
 
   bool Changed = false;
@@ -435,11 +383,7 @@ bool SimplifyDRuntimeCalls::runOnce(Function &F, const DataLayout *DL,
       --ciIt;
       Builder.SetInsertPoint(&BB, I);
 
-#if LDC_LLVM_VER >= 308
       AliasAnalysis &AA = AAP.getAAResults();
-#else
-      AliasAnalysis &AA = AAP;
-#endif
       // Try to optimize this call.
       Value *Result = OMI->second->OptimizeCall(CI, Changed, DL, AA, Builder);
       if (Result == nullptr) {
@@ -455,14 +399,8 @@ bool SimplifyDRuntimeCalls::runOnce(Function &F, const DataLayout *DL,
       if (Result == CI) {
         assert(CI->use_empty());
         ++NumDeleted;
-#if LDC_LLVM_VER < 308
-        AA.deleteValue(CI);
-#endif
       } else {
         ++NumSimplified;
-#if LDC_LLVM_VER < 308
-        AA.replaceWithNewValue(CI, Result);
-#endif
 
         if (!CI->use_empty()) {
           CI->replaceAllUsesWith(Result);
