@@ -9,8 +9,8 @@
 //
 //===----------------------------------------------------------------------===//
 
+#include "dmd/errors.h"
 #include "dmd/ldcbindings.h"
-#include "dmd/mars.h"
 #include "dmd/mtype.h"
 #include "dmd/target.h"
 #include "driver/cl_options.h"
@@ -78,6 +78,9 @@ unsigned getCriticalSectionSize(const Param &params) {
     break;
   }
 
+  if (arch == llvm::Triple::wasm32 || arch == llvm::Triple::wasm64)
+    return 0;
+
 #ifndef _MSC_VER
   unsigned hostSize = sizeof(pthread_mutex_t);
   warning(Loc(), "Assuming critical section size = %u bytes", hostSize);
@@ -128,7 +131,6 @@ void Target::_init(const Param &params) {
 #endif
 
   RealProperties.nan = CTFloat::nan;
-  RealProperties.snan = CTFloat::initVal;
   RealProperties.infinity = CTFloat::infinity;
 
   if (targetRealSemantics == IEEEdouble) {
