@@ -7,19 +7,21 @@
 //
 //===----------------------------------------------------------------------===//
 
-#include "gen/llvm.h"
-#include "aggregate.h"
-#include "declaration.h"
-#include "init.h"
-#include "mtype.h"
-#include "target.h"
+#include "ir/iraggr.h"
+
+#include "dmd/aggregate.h"
+#include "dmd/declaration.h"
+#include "dmd/expression.h"
+#include "dmd/init.h"
+#include "dmd/mtype.h"
+#include "dmd/target.h"
 #include "gen/irstate.h"
+#include "gen/llvm.h"
 #include "gen/llvmhelpers.h"
 #include "gen/logger.h"
 #include "gen/mangling.h"
 #include "gen/tollvm.h"
-#include "ir/iraggr.h"
-#include "irdsymbol.h"
+#include "ir/irdsymbol.h"
 #include "ir/irtypeclass.h"
 #include "ir/irtypestruct.h"
 #include <algorithm>
@@ -144,12 +146,12 @@ IrAggr::createInitializerConstant(const VarInitMap &explicitInitializers) {
   if (type->ty == Tclass) {
     // add vtbl
     constants.push_back(getVtblSymbol());
-    offset += Target::ptrsize;
+    offset += target.ptrsize;
 
     // add monitor (except for C++ classes)
     if (!aggrdecl->isClassDeclaration()->isCPPclass()) {
       constants.push_back(getNullValue(getVoidPtrType()));
-      offset += Target::ptrsize;
+      offset += target.ptrsize;
     }
   }
 
@@ -208,7 +210,7 @@ void IrAggr::addFieldInitializers(
     if (cd->vtblInterfaces && cd->vtblInterfaces->dim > 0) {
       // Align interface infos to pointer size.
       unsigned aligned =
-          (offset + Target::ptrsize - 1) & ~(Target::ptrsize - 1);
+          (offset + target.ptrsize - 1) & ~(target.ptrsize - 1);
       if (offset < aligned) {
         add_zeros(constants, offset, aligned);
         offset = aligned;
@@ -217,7 +219,7 @@ void IrAggr::addFieldInitializers(
       size_t inter_idx = interfacesWithVtbls.size();
       for (auto bc : *cd->vtblInterfaces) {
         constants.push_back(getInterfaceVtblSymbol(bc, inter_idx));
-        offset += Target::ptrsize;
+        offset += target.ptrsize;
         inter_idx++;
 
         if (populateInterfacesWithVtbls)
