@@ -12,8 +12,7 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef JIT_CONTEXT_H
-#define JIT_CONTEXT_H
+#pragma once
 
 #include <map>
 #include <memory>
@@ -68,11 +67,19 @@ private:
   llvm::llvm_shutdown_obj shutdownObj;
   std::unique_ptr<llvm::TargetMachine> targetmachine;
   const llvm::DataLayout dataLayout;
+#if LDC_LLVM_VER >= 800
+  using ObjectLayerT = llvm::orc::LegacyRTDyldObjectLinkingLayer;
+  using ListenerLayerT =
+    llvm::orc::LegacyObjectTransformLayer<ObjectLayerT, ModuleListener>;
+  using CompileLayerT =
+    llvm::orc::LegacyIRCompileLayer<ListenerLayerT, llvm::orc::SimpleCompiler>;
+#else
   using ObjectLayerT = llvm::orc::RTDyldObjectLinkingLayer;
   using ListenerLayerT =
       llvm::orc::ObjectTransformLayer<ObjectLayerT, ModuleListener>;
   using CompileLayerT =
       llvm::orc::IRCompileLayer<ListenerLayerT, llvm::orc::SimpleCompiler>;
+#endif
 #if LDC_LLVM_VER >= 700
   using ModuleHandleT = llvm::orc::VModuleKey;
   std::shared_ptr<llvm::orc::SymbolStringPool> stringPool;
@@ -110,8 +117,8 @@ public:
   llvm::TargetMachine &getTargetMachine() { return *targetmachine; }
   const llvm::DataLayout &getDataLayout() const { return dataLayout; }
 
-  bool addModule(std::unique_ptr<llvm::Module> module,
-                 llvm::raw_ostream *asmListener);
+  llvm::Error addModule(std::unique_ptr<llvm::Module> module,
+                        llvm::raw_ostream *asmListener);
 
   llvm::JITSymbol findSymbol(const std::string &name);
 
@@ -143,5 +150,3 @@ private:
   std::shared_ptr<llvm::JITSymbolResolver> createResolver();
 #endif
 };
-
-#endif // JIT_CONTEXT_H
